@@ -261,6 +261,14 @@ mod couch_rs_tests {
             let _ = client.destroy_db(dbname);
         }
 
+        #[tokio::test]
+        async fn should_not_exist() {
+            let client = Client::new_local_test().unwrap();
+            let dbname = "should_not_exist";
+            let dbw = client.exists(dbname).await;
+            assert!(!client.exists(dbname).await.unwrap());
+        }
+
         #[tokio::test]
         async fn should_create_a_document() {
             let client = Client::new_local_test().unwrap();
